==> bitcoin-abc-0.27.15.tar.gz: bitcoin-abc-0.27.15/cashtab/src/transactions/__tests__/index.test.js <==
// Copyright (c) 2023 The Bitcoin developers
// Distributed under the MIT software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.
import { sendXec } from 'transactions';
import { MockChronikClient } from '../../../../apps/mock-chronik-client';
import { sendXecVectors } from '../fixtures/vectors';

describe('Improved Cashtab transaction broadcasting functions', () => {
    // Unit test for each vector in fixtures for the sendingXecToSingleAddress case
    const { txs, errors } = sendXecVectors;

    // Successfully built and broadcast txs
    txs.forEach(async tx => {
        const { description, wallet, targetOutputs, feeRate, txid, hex } = tx;
        it(`sendXec: ${description}`, async () => {
            const chronik = new MockChronikClient();
            chronik.setMock('broadcastTx', {
                input: hex,
                output: { txid },
            });
            expect(
                await sendXec(chronik, wallet, targetOutputs, feeRate),
            ).toStrictEqual({ hex, response: { txid } });
        });
    });

    // Error cases
    errors.forEach(async error => {
        const { description, wallet, targetOutputs, feeRate, msg, hex } = error;

        it(`sendXec: ${description}`, async () => {
            const chronik = new MockChronikClient();
            // e.g. ('block', {input: '', output: ''})
            if (typeof hex !== 'undefined') {
                // For error cases that are not thrown until after the tx is successfully built,
                // set a tx broadcast error that can be thrown by the broadcasting eCash node
                chronik.setMock('broadcastTx', {
                    input: hex,
                    output: new Error(msg),
                });
            }

            await expect(
                sendXec(chronik, wallet, targetOutputs, feeRate),
            ).rejects.toThrow(msg);
        });
    });
});

==> bitcoin-abc-0.28.6.tar.gz: bitcoin-abc-0.28.6/cashtab/src/transactions/__tests__/index.test.js <==
// Copyright (c) 2023 The Bitcoin developers
// Distributed under the MIT software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.
import { sendXec, getMultisendTargetOutputs } from 'transactions';
import { MockChronikClient } from '../../../../apps/mock-chronik-client';
import {
    sendXecVectors,
    getMultisendTargetOutputsVectors,
} from '../fixtures/vectors';

describe('Improved Cashtab transaction broadcasting function', () => {
    // Unit test for each vector in fixtures for the sendingXecToSingleAddress case
    const { txs, errors } = sendXecVectors;

    // Successfully built and broadcast txs
    txs.forEach(async tx => {
        const { description, wallet, targetOutputs, feeRate, txid, hex } = tx;
        it(`sendXec: ${description}`, async () => {
            const chronik = new MockChronikClient();
            chronik.setMock('broadcastTx', {
                input: hex,
                output: { txid },
            });
            expect(
                await sendXec(chronik, wallet, targetOutputs, feeRate),
            ).toStrictEqual({ hex, response: { txid } });
        });
    });

    // Error cases
    errors.forEach(async error => {
        const { description, wallet, targetOutputs, feeRate, msg, hex } = error;

        it(`sendXec: ${description}`, async () => {
            const chronik = new MockChronikClient();
            // e.g. ('block', {input: '', output: ''})
            if (typeof hex !== 'undefined') {
                // For error cases that are not thrown until after the tx is successfully built,
                // set a tx broadcast error that can be thrown by the broadcasting eCash node
                chronik.setMock('broadcastTx', {
                    input: hex,
                    output: new Error(msg),
                });
            }

            await expect(
                sendXec(chronik, wallet, targetOutputs, feeRate),
            ).rejects.toThrow(msg);
        });
    });
});

describe('Forming multisend targetOutputs', () => {
    // Unit test for each vector in fixtures for the getMultisendTargetOutputs case
    const { formedOutputs, errors } = getMultisendTargetOutputsVectors;

    // Successfully built and broadcast txs
    formedOutputs.forEach(async formedOutput => {
        const { description, userMultisendInput, targetOutputs } = formedOutput;
        it(`getMultisendTargetOutputs: ${description}`, () => {
            expect(getMultisendTargetOutputs(userMultisendInput)).toStrictEqual(
                targetOutputs,
            );
        });
    });

    // Error cases
    errors.forEach(async error => {
        const { description, userMultisendInput, msg } = error;

        it(`getMultisendTargetOutputs throws error for: ${description}`, () => {
            expect(() => getMultisendTargetOutputs(userMultisendInput)).toThrow(
                msg,
            );
        });
    });
});
